/*
 * vsidarch.h - UI for sidplayer
 *
 * Written by
 *  Andreas Dehmel <zarquon@t-online.de>
 *
 * This file is part of VICE, the Versatile Commodore Emulator.
 * See README for copyright notice.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 *
 */

#ifndef VICE_VSID_ARCH_H_
#define VICE_VSID_ARCH_H_

/* Window icons */
#define Icon_VSid_Name       1
#define Icon_VSid_Author     2
#define Icon_VSid_Copyright  3
#define Icon_VSid_TotalTunes 7
#define Icon_VSid_Speed	     8
#define Icon_VSid_Tune       11
#define Icon_VSid_NextTune   12
#define Icon_VSid_PrevTune   13
#define Icon_VSid_StopTune   14
#define Icon_VSid_Default    15
#define Icon_VSid_PlayTime   17
#define Icon_VSid_Pause      19

#endif
